<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        {% block head_meta %}
            <title>{{ title }} | Tiempo </title>
        {% endblock %}

        {% block css %}{% endblock %}
        <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
        <!--[if lt IE 9]>
            <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
            <script src="https://oss.maxcdn.com/libs/respond.js/1.3.0/respond.min.js"></script>
        <![endif]-->
    </head>

    <body {% block body_style %}{% endblock %}>
        <!-- Wrap all page content here -->
        <div id="wrap">
            <!-- Fixed navbar -->
            {% block header %}{% endblock%}
            <!-- Begin page content -->
            {% block content %}{% endblock %}
            <!-- End page content -->
        </div>
        <!-- End wrap -->
        {% block modals %}{% endblock %}
        <!-- Success/error message modals -->
    </body>
</html>
