<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>{{ brief }}</title>
        <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" media="screen" charset="utf-8">
    </head>

    <body>
        <!-- Wrap all page content here -->
        <div id="wrap">
            <!-- Begin page content -->
            {% block content %}
            <div class="container">
                <h1>{{brief}}</h1>
                <h3>{{detail}}</h3>
            </div>
            {% endblock %}
            <!-- End page content -->
        </div>
        <!-- End wrap -->
    </body>
</html>
